Changelog
=========


0.1.20 (2020-01-18)
-------------------

Changes
~~~~~~~
- Adding python 3.7 support. [Luis Alejandro Martínez Faneyth]
- Removing support for python 2.7 and 3.4. Adding support for python 3.8
  and PyPy3. [Luis Alejandro Martínez Faneyth]
- Improving docstrings. [Luis Alejandro Martínez Faneyth]
- Changing branding. [Luis Alejandro Martínez Faneyth]

Other
~~~~~
- Scheduled monthly dependency update for November (#47) [Luis Alejandro
  Martínez Faneyth, pyup.io bot]

  * Update setuptools from 41.0.1 to 41.6.0

  * Update setuptools from 41.0.1 to 41.6.0

  * Update pip from 19.1.1 to 19.3.1

  * Update flake8 from 3.7.7 to 3.7.9

  * Update pydocstyle from 3.0.0 to 4.0.1

  * Update virtualenv from 16.6.1 to 16.7.7

  * Update coverage from 4.5.3 to 4.5.4

  * Update tox from 3.13.1 to 3.14.0

  * Update coveralls from 1.8.1 to 1.8.2
- Scheduled monthly dependency update for October (#46) [Luis Alejandro
  Martínez Faneyth, pyup.io bot]

  * Update setuptools from 41.0.1 to 41.2.0

  * Update setuptools from 41.0.1 to 41.2.0

  * Update pip from 19.1.1 to 19.2.3

  * Update flake8 from 3.7.7 to 3.7.8

  * Update pydocstyle from 3.0.0 to 4.0.1

  * Update virtualenv from 16.6.1 to 16.7.5

  * Update coverage from 4.5.3 to 4.5.4

  * Update tox from 3.13.1 to 3.14.0

  * Update coveralls from 1.8.1 to 1.8.2
- Scheduled monthly dependency update for September (#45) [Luis
  Alejandro Martínez Faneyth, pyup.io bot]

  * Update setuptools from 41.0.1 to 41.2.0

  * Update setuptools from 41.0.1 to 41.2.0

  * Update pip from 19.1.1 to 19.2.3

  * Update flake8 from 3.7.7 to 3.7.8

  * Update pydocstyle from 3.0.0 to 4.0.1

  * Update virtualenv from 16.6.1 to 16.7.4

  * Update coverage from 4.5.3 to 4.5.4

  * Update tox from 3.13.1 to 3.13.2

  * Update coveralls from 1.8.1 to 1.8.2
- Scheduled monthly dependency update for August (#44) [pyup.io bot]

  * Update pip from 19.1.1 to 19.2.1

  * Update flake8 from 3.7.7 to 3.7.8

  * Update pydocstyle from 3.0.0 to 4.0.0

  * Update virtualenv from 16.6.1 to 16.7.2

  * Update coverage from 4.5.3 to 4.5.4

  * Update tox from 3.13.1 to 3.13.2

  * Update coveralls from 1.8.1 to 1.8.2
- Scheduled monthly dependency update for July (#43) [pyup.io bot]

  * Update setuptools from 40.8.0 to 41.0.1

  * Update setuptools from 40.8.0 to 41.0.1

  * Update pip from 19.0.3 to 19.1.1

  * Update virtualenv from 16.4.3 to 16.6.1

  * Update coverage from 4.5.2 to 4.5.3

  * Update tox from 3.7.0 to 3.13.1

  * Update coveralls from 1.6.0 to 1.8.1
- Scheduled monthly dependency update for March (#39) [pyup.io bot]

  * Update setuptools from 40.7.2 to 40.8.0

  * Update setuptools from 40.7.2 to 40.8.0

  * Update pip from 19.0.1 to 19.0.3

  * Update flake8 from 3.7.4 to 3.7.7

  * Update virtualenv from 16.3.0 to 16.4.3

  * Update coveralls from 1.5.1 to 1.6.0
- Scheduled monthly dependency update for February (#38) [pyup.io bot]

  * Update setuptools from 40.6.2 to 40.7.2

  * Update setuptools from 40.6.2 to 40.7.2

  * Update pip from 18.1 to 19.0.1

  * Update flake8 from 3.6.0 to 3.7.4

  * Update virtualenv from 16.1.0 to 16.3.0

  * Update gitchangelog from 3.0.3 to 3.0.4

  * Update tox from 3.5.3 to 3.7.0
- Scheduled monthly dependency update for December (#36) [pyup.io bot]

  * Update setuptools from 40.0.0 to 40.6.2

  * Update setuptools from 40.0.0 to 40.6.2

  * Update pip from 18.0 to 18.1

  * Update flake8 from 3.5.0 to 3.6.0

  * Update wheel from 0.31.1 to 0.32.3

  * Update tox from 3.1.2 to 3.5.3

  * Update pydocstyle from 2.1.1 to 3.0.0

  * Update virtualenv from 16.0.0 to 16.1.0

  * Update coverage from 4.5.1 to 4.5.2

  * Update coveralls from 1.3.0 to 1.5.1


0.1.19 (2018-12-12)
-------------------

Changes
~~~~~~~
- Removing support for python 2.6 & 3.2. [Luis Alejandro Martínez
  Faneyth]

Other
~~~~~
- Scheduled monthly dependency update for August (#32) [pyup.io bot]

  * Update setuptools from 39.2.0 to 40.0.0

  * Update setuptools from 39.2.0 to 40.0.0

  * Update pip from 10.0.1 to 18.0

  * Update tox from 3.0.0 to 3.1.2
- Scheduled monthly dependency update for June (#31) [pyup.io bot]

  * Update setuptools from 39.0.1 to 39.2.0

  * Update pip from 9.0.3 to 10.0.1

  * Update virtualenv from 15.2.0 to 16.0.0

  * Update tox from 2.9.1 to 3.0.0

  * Pin setuptools to latest version 39.2.0

  * Update requirements-dev.txt

  * Update requirements.txt
- Scheduled monthly dependency update for May (#30) [pyup.io bot]

  * Update setuptools from 39.0.1 to 39.1.0

  * Update pip from 9.0.3 to 10.0.1

  * Update tox from 2.9.1 to 3.0.0

  * Pin setuptools to latest version 39.1.0
- Scheduled monthly dependency update for April (#28) [pyup.io bot]

  * Update setuptools from 36.3.0 to 39.0.1

  * Update setuptools from 36.3.0 to 39.0.1

  * Update pip from 9.0.1 to 9.0.3

  * Update flake8 from 3.4.1 to 3.5.0

  * Update pydocstyle from 2.0.0 to 2.1.1

  * Update virtualenv from 15.1.0 to 15.2.0

  * Update coverage from 4.4.1 to 4.5.1

  * Update wheel from 0.29.0 to 0.30.0

  * Update tox from 2.7.0 to 2.9.1

  * Update coveralls from 1.2.0 to 1.3.0
- Scheduled monthly dependency update for March (#27) [pyup.io bot]

  * Update setuptools from 36.3.0 to 38.5.1

  * Update setuptools from 36.3.0 to 38.5.1

  * Update flake8 from 3.4.1 to 3.5.0

  * Update pydocstyle from 2.0.0 to 2.1.1

  * Update coverage from 4.4.1 to 4.5.1

  * Update wheel from 0.29.0 to 0.30.0

  * Update tox from 2.7.0 to 2.9.1
- Scheduled monthly dependency update for February (#26) [pyup.io bot]

  * Update setuptools from 36.3.0 to 38.4.0

  * Update setuptools from 36.3.0 to 38.4.0

  * Update flake8 from 3.4.1 to 3.5.0

  * Update pydocstyle from 2.0.0 to 2.1.1

  * Update coverage from 4.4.1 to 4.4.2

  * Update wheel from 0.29.0 to 0.30.0

  * Update tox from 2.7.0 to 2.9.1
- Scheduled monthly dependency update for January (#25) [pyup.io bot]

  * Update setuptools from 36.3.0 to 38.2.5

  * Update setuptools from 36.3.0 to 38.2.5

  * Update flake8 from 3.4.1 to 3.5.0

  * Update pydocstyle from 2.0.0 to 2.1.1

  * Update coverage from 4.4.1 to 4.4.2

  * Update wheel from 0.29.0 to 0.30.0

  * Update tox from 2.7.0 to 2.9.1
- Scheduled monthly dependency update for December (#24) [pyup.io bot]

  * Update setuptools from 36.3.0 to 38.2.3

  * Update setuptools from 36.3.0 to 38.2.3

  * Update flake8 from 3.4.1 to 3.5.0

  * Update pydocstyle from 2.0.0 to 2.1.1

  * Update coverage from 4.4.1 to 4.4.2

  * Update wheel from 0.29.0 to 0.30.0

  * Update tox from 2.7.0 to 2.9.1
- Scheduled monthly dependency update for November (#23) [pyup.io bot]

  * Update setuptools from 36.3.0 to 36.6.0

  * Update setuptools from 36.3.0 to 36.6.0

  * Update flake8 from 3.4.1 to 3.5.0

  * Update pydocstyle from 2.0.0 to 2.1.1

  * Update wheel from 0.29.0 to 0.30.0

  * Update tox from 2.7.0 to 2.9.1
- Scheduled monthly dependency update for October (#22) [pyup.io bot]

  * Update setuptools from 36.3.0 to 36.5.0

  * Update setuptools from 36.3.0 to 36.5.0

  * Update wheel from 0.29.0 to 0.30.0

  * Update tox from 2.7.0 to 2.9.1
- Scheduled monthly dependency update for September (#21) [pyup.io bot]

  * Pin setuptools to latest version 36.3.0

  * Pin setuptools to latest version 36.3.0

  * Pin pip to latest version 9.0.1

  * Pin flake8 to latest version 3.4.1

  * Pin pydocstyle to latest version 2.0.0

  * Pin virtualenv to latest version 15.1.0

  * Pin coverage to latest version 4.4.1

  * Pin gitchangelog to latest version 3.0.3

  * Pin bumpversion to latest version 0.5.3

  * Pin wheel to latest version 0.29.0

  * Pin tox to latest version 2.7.0

  * Pin coveralls to latest version 1.2.0


0.1.18 (2018-04-18)
-------------------

Fix
~~~
- Removing conditional dependencies from requirements.txt because it is
  not supported for instal_requires with setuptools < 36.2.1, so it
  breakes py26 and py32 tests. [Luis Alejandro Martínez Faneyth]


0.1.17 (2018-04-15)
-------------------

Fix
~~~
- Fixing python 3.2 support. [Luis Alejandro Martínez Faneyth]


0.1.16 (2018-04-14)
-------------------

Fix
~~~
- Pinning versions of software to avoid CI breaks over time. [Luis
  Alejandro Martínez Faneyth]
- Fixing PEP8 styleguide. [Luis Alejandro Martínez Faneyth]

Other
~~~~~
- Add Gitter badge (#29) [The Gitter Badger]


0.1.15 (2017-08-02)
-------------------

Changes
~~~~~~~
- Adding development tools to requirements. [Luis Alejandro Martínez
  Faneyth]


0.1.14 (2017-08-02)
-------------------

Changes
~~~~~~~
- Adding pyup configuration. [Luis Alejandro Martínez Faneyth]


0.1.13 (2017-08-02)
-------------------

Changes
~~~~~~~
- Improving parsing of requirements for setuptools. [Luis Alejandro
  Martínez Faneyth]
- Adjusting version of setuptools for python 2.6. [Luis Alejandro
  martínez Faneyth]


0.1.12 (2017-07-17)
-------------------

Changes
~~~~~~~
- Adjusting environment markers for different python versions. [Luis
  Alejandro martínez Faneyth]
- Removing rq.filter notation. [Luis Alejandro martínez Faneyth]
- Adding support for pyup. [Luis Alejandro martínez Faneyth]
- Migrating to environment markers in requirements for simpler
  management. [Luis Alejandro martínez Faneyth]
- Improving README. [Luis Alejandro martínez Faneyth]

Fix
~~~
- Fixing pydocstyle tests. [Luis Alejandro martínez Faneyth]


0.1.11 (2017-05-20)
-------------------

Fix
~~~
- Fixing python 3.5+ support. [Luis Alejandro Martínez Faneyth]


0.1.10 (2017-05-19)
-------------------

Fix
~~~
- Fixing python 3.2 support. [Luis Alejandro Martínez Faneyth]
- Fixing python 3.2 tests. [Luis Alejandro Martínez Faneyth]


0.1.8 (2017-05-19)
------------------

Fix
~~~
- Fixing python 3.5+ support. [Luis Alejandro Martínez Faneyth]


0.1.7 (2017-01-16)
------------------

Fix
~~~
- Hotfix: Fixing Travis build because documentation typo. [Luis
  Alejandro Martínez Faneyth]


0.1.6 (2017-01-16)
------------------

Changes
~~~~~~~
- Improving python 3 compatibility. [REF] Renaming pipsalabim.core.util
  to pipsalabim.core.utils. [Luis Alejandro Martínez Faneyth]


0.1.5 (2017-01-16)
------------------

Fix
~~~
- Fixing python3 compatibility. [Luis Alejandro Martínez Faneyth]


0.1.4 (2017-01-15)
------------------

Changes
~~~~~~~
- Fixing python 2.6 support on the logger module (closes #11). [ADD]
  Implementing functional test on .travis.yml. [Luis Alejandro Martínez
  Faneyth]

Fix
~~~
- Fixing testing for python 3.2 and 2.6. [Luis Alejandro Martínez
  Faneyth]

Other
~~~~~
- New: dev: Adding support to python 2.6 (closes #10). chg: dev:
  Removing configurations for codeclimate. [Luis Alejandro Martínez
  Faneyth]


0.1.3 (2017-01-04)
------------------

New
~~~
- Adding gitchangelog configuration file. [Luis Alejandro Martínez
  Faneyth]
- Adding support to python 2.6 (closes #10). [Luis Alejandro Martínez
  Faneyth]

Changes
~~~~~~~
- Adding new changelog entries. [Luis Alejandro Martínez Faneyth]

Fix
~~~
- Fixing testing for python 3.2 and 2.6. [Luis Alejandro Martínez
  Faneyth]
- Fixing bumpversion config. [Luis Alejandro Martínez Faneyth]
- Fixing typo. [Luis Alejandro Martínez Faneyth]

Other
~~~~~
- Bump version: 0.1.0 → 0.1.1. [Luis Alejandro Martínez Faneyth]


0.1.2 (2017-01-04)
------------------

New
~~~
- Adding gitchangelog configuration file. [Luis Alejandro Martínez
  Faneyth]
- Adding support to python 2.6 (closes #10). [Luis Alejandro Martínez
  Faneyth]


0.1.1 (2016-11-24)
------------------

New
~~~
- Adding Contributor License Agreement. [Luis Alejandro Martínez
  Faneyth]

Changes
~~~~~~~
- Adding new changelog entries. [Luis Alejandro Martínez Faneyth]

Fix
~~~
- Fixing bumpversion config. [Luis Alejandro Martínez Faneyth]
- Fixing typo. [Luis Alejandro Martínez Faneyth]
- Catching exceptions on package discovery as described in #3. [REF]
  Using find_packages from setuptools to discover packages. [Luis
  Alejandro Martínez Faneyth]

Other
~~~~~
- Bump version: 0.1.0 → 0.1.1. [Luis Alejandro Martínez Faneyth]


0.1.0 (2016-11-23)
------------------

Changes
~~~~~~~
- Improving README. [Luis Alejandro Martínez Faneyth]
- Improving RST markup. [Luis Alejandro Martínez Faneyth]
- Improving documentation. [REF] Configuring codeclimate. [Luis
  Alejandro Martínez Faneyth]
- Completing API documentation. [REF] Finishing commandline programming.
  [Luis Alejandro Martínez Faneyth]
- Temporarily increasing McCabe index to 20 to pass tests. [REF]
  Updating requirements versions. [REF] Improving documentation. [Luis
  Alejandro Martínez Faneyth]
- Improving documentation. [Luis Alejandro Martínez Faneyth]
- Correcting code style. [Luis Alejandro Martínez Faneyth]
- Improving documentation of functions. [REF] Porting snakefood's code
  to python 3.x. [REF] Various coe style corrections. [Luis Alejandro
  Martínez Faneyth]
- Adding code from snakefood because it doesn't support py3k. [REF]
  Fixing PEP8 errors. [Luis Alejandro Martínez Faneyth]
- Improving documentation. [REF] Adding download progress to "update"
  command. [Luis Alejandro Martínez Faneyth]
- Improving documentation. [REF] Updating visual style. [REF]
  Reorganizing code. [Luis Alejandro Martínez Faneyth]
- Updating visual style. [Luis Alejandro Martínez Faneyth]
- General refactoring of structure and code. [ADD] Adding projecto
  boilerplate. [ADD] Programming of "guess" command. [ADD] Adding visual
  style. [Luis Alejandro Martínez Faneyth]

Fix
~~~
- Correcting minor issues. [Luis Alejandro Martínez Faneyth]
- Fixing typo. [Luis Alejandro Martínez Faneyth]

Other
~~~~~
- 0.1.0 release. [Luis Alejandro Martínez Faneyth]
- Add Gitter badge. [The Gitter Badger]
- [DEL] Removing unnecessary tests. [REF] Reorganizing code. [REF]
  Documenting functions. [REF] Starting some unit tests. [Luis Alejandro
  Martínez Faneyth]
- Initial commit. [Luis Alejandro Martínez Faneyth]


